@@ -323,21 +323,21 @@ sub new {
   my $class = shift;
   
   my $self = {@_};
-
+  
   bless $self, ref $class || $class;
   
   my $file_optional = $self->file_optional;
   
   my $file = $self->file;
   if (!$file_optional && !defined $file) {
-    confess "\"file\" option must be specified";
+    confess "The \"file\" field must be defined";
   }
   
   # cc
   unless (defined $self->{cc}) {
     $self->cc($Config{cc});
   }
-
+  
   # ccflags
   unless (defined $self->{ccflags}) {
     $self->ccflags([]);
@@ -832,11 +832,11 @@ sub _remove_ext_from_config_file {
 
 =head1 Name
 
-SPVM::Builder::Config - Compiler and Linker Configuration
+SPVM::Builder::Config - Compiler and Linker Configuration for Native Classes
 
 =head1 Description
 
-The SPVM::Builder::Config class has methods to manipulate compiler and linker configuration.
+The SPVM::Builder::Config class has methods to manipulate compiler and linker configuration for L<native classes|SPVM::Document::NativeClass>.
 
 =head1 Usage
 
@@ -879,6 +879,10 @@ The SPVM::Builder::Config class has methods to manipulate compiler and linker co
   # Get resouce information
   my $resource = $config->get_resource('TestCase::Resource::Zlib');
 
+=head1 Details
+
+See L<SPVM::Document::NativeClass> about creating native classes and those configuration.
+
 =head1 Fields
 
 =head2 ext
@@ -923,9 +927,9 @@ Examples:
   my $include_dirs = $config->include_dirs;
   $config->include_dirs($include_dirs);
 
-Gets and sets the C<include_dirs> field, an array reference of directories for native header files.
+Gets and sets the C<include_dirs> field, an array reference of header file search directories.
 
-The values of this field are converted to the C<-I> options given the compiler L</"cc">.
+The values of this field are converted to the C<-I> options for the compiler L</"cc">.
 
   # -I/path1 -I/path2
   $config->include_dirs('/path1', '/path2');
@@ -935,48 +939,46 @@ The values of this field are converted to the C<-I> options given the compiler L
   my $spvm_core_include_dir = $config->spvm_core_include_dir;
   $config->spvm_core_include_dir($spvm_core_include_dir);
 
-Gets and sets the C<spvm_core_include_dir> field, the directory for SPVM core header files.
+Gets and sets the C<spvm_core_include_dir> field, the SPVM core header file search directory.
 
-This field are converted to the C<-I> option given the compiler L</"cc">.
+This field are converted to the C<-I> option for the compiler L</"cc">.
 
 =head2 native_include_dir
 
   my $native_include_dir = $config->native_include_dir;
   $config->native_include_dir($native_include_dir);
 
-Gets and sets the C<native_include_dir> field, the directory for native header files in this native class.
+Gets and sets the C<native_include_dir> field, the search directory for header files of this native class.
 
-This field are converted to the C<-I> option given the compiler L</"cc">.
+This field are converted to the C<-I> option for the compiler L</"cc">.
 
 =head2 native_src_dir
 
   my $native_src_dir = $config->native_src_dir;
   $config->native_src_dir($native_src_dir);
 
-Gets and sets the C<native_src_dir> field, the directory for native source files in this native class.
-
-This directory is where the source files added by the L</"add_source_file"> method are searched.
+Gets and sets the C<native_src_dir> field, the search directory for source files of this native class.
 
 =head2 ccflags
 
   my $ccflags = $config->ccflags;
   $config->ccflags($ccflags);
 
-Gets and sets the C<ccflags> field, an array reference of compiler flags given the compile L</"cc">.
+Gets and sets the C<ccflags> field, an array reference of compiler options for the compiler L</"cc">.
 
 =head2 dynamic_lib_ccflags
 
   my $dynamic_lib_ccflags = $config->dynamic_lib_ccflags;
   $config->dynamic_lib_ccflags($dynamic_lib_ccflags);
 
-Gets and sets the C<dynamic_lib_ccflags> field, an array reference of compiler flags given the compile L</"cc"> used when the linker generates a dynamic link file.
+Gets and sets the C<dynamic_lib_ccflags> field, an array reference of dynamic link options for the compiler L</"cc">.
 
 =head2 thread_ccflags
 
   my $thread_ccflags = $config->thread_ccflags;
   $config->thread_ccflags($thread_ccflags);
 
-Gets and sets the C<thread_ccflags> field, an array reference of compiler flags given the compile L</"cc"> for threads.
+Gets and sets the C<thread_ccflags> field, an array reference of thread options for the compiler L</"cc">.
 
 =head2 std
 
@@ -985,7 +987,7 @@ Gets and sets the C<thread_ccflags> field, an array reference of compiler flags
 
 Gets and sets the C<std> field, a language standard.
 
-This field is converted to the C<-std> option given the compiler L</"cc">.
+This field is converted to the C<-std> option for the compiler L</"cc">.
 
 Examples:
   
@@ -1009,7 +1011,7 @@ Examples:
   my $optimize = $config->optimize;
   $config->optimize($optimize);
 
-Gets and sets the C<optimize> field, an option given the compiler L</"cc"> for optimization.
+Gets and sets the C<optimize> field, an optimization option for the compiler L</"cc">.
 
 Examples:
 
@@ -1022,7 +1024,7 @@ Examples:
   my $source_files = $config->source_files;
   $config->source_files($source_files);
 
-Gets and sets the C<source_files> field, an array reference of native source files.
+Gets and sets the C<source_files> field, an array reference of source files used by this native class.
 
 The source file names are specified as relative paths from the L</"native_src_dir"> field.
 
@@ -1033,12 +1035,9 @@ The source file names are specified as relative paths from the L</"native_src_di
 
 Gets and sets the C<before_compile_cbs> field, an array reference of callbacks called just before the compile command L</"cc"> is executed.
 
-=head2 before_link_cbs
+The 1th argument of the callback is a L<SPVM::Builder::Config> object.
 
-  my $before_link_cbs = $config->before_link_cbs;
-  $config->before_link_cbs($before_link_cbs);
-
-Gets and sets the C<before_link_cbs> field, an array reference of callbacks called just before the link command L</"ld"> is executed.
+The 2th argument of the callback is a L<SPVM::Builder::CompileInfo> object.
 
 =head2 ld
 
@@ -1047,7 +1046,7 @@ Gets and sets the C<before_link_cbs> field, an array reference of callbacks call
 
 Gets and sets the C<ld> field, a linker name.
 
-Excamples:
+Examples:
 
   $config->ld('gcc');
   $config->ld('g++');
@@ -1057,71 +1056,73 @@ Excamples:
   my $lib_dirs = $config->lib_dirs;
   $config->lib_dirs($lib_dirs);
 
-Gets and sets the C<lib_dirs> field.
+Gets and sets the C<lib_dirs> field, an array reference of library search path for the linker L</"ld">.
 
-This field is an array reference that contains the directories that libraries are searched for by the linker.
-
-This is same as C<-L> option of the compiler L</"cc">.
+This is equivalent to the C<-L> option for the linker L</"ld">.
 
 =head2 libs
 
   my $libs = $config->libs;
   $config->libs($libs);
 
-Gets and sets the C<libs> field.
-
-This field is an array reference that contains library names or L<SPVM::Builder::LibInfo> objects. These libraries are linked by L<SPVM::Builder::CC/"link"> method.
+Gets and sets the C<libs> field, an array reference of library names or L<SPVM::Builder::LibInfo> objects for the linker L</"ld">.
 
 =head2 ldflags
 
   my ldflags = $config->ldflags;
   $config->ldflags(ldflags);
 
-Gets and sets the C<ldflags> field.
-
-This field is an array reference that contains linker flags.
+Gets and sets the C<ldflags> field, an array reference of options for the linker L</"ld">.
 
 =head2 dynamic_lib_ldflags
 
   my dynamic_lib_ldflags = $config->dynamic_lib_ldflags;
   $config->dynamic_lib_ldflags(dynamic_lib_ldflags);
 
-Gets and sets the C<dynamic_lib_ldflags> field, an array reference of the linker flags for the linker L</"ld">.
+Gets and sets the C<dynamic_lib_ldflags> field, an array reference of dynamic library options for the linker L</"ld">.
 
 =head2 thread_ldflags
 
   my thread_ldflags = $config->thread_ldflags;
   $config->thread_ldflags(thread_ldflags);
 
-Gets and sets the C<thread_ldflags> field, an array reference of the linker flags for thread for the linker L</"ld">.
+Gets and sets the C<thread_ldflags> field, an array reference of thread options for the linker L</"ld">.
 
 =head2 static_lib_ldflag
 
   my static_lib_ldflag = $config->static_lib_ldflag;
   $config->static_lib_ldflag(static_lib_ldflag);
 
-Gets and sets the C<static_lib_ldflag> field, an array reference that contains the begining and the end of static linking option for each static library of L</"static_libs">.
+Gets and sets the C<static_lib_ldflag> field, an array reference of options that specify the begining and end of a static library.
 
-Excamples:
-  
+Examples:
   
   # -Wl,-Bstatic -lfoo -Wl,-Bdynamic
   $config->static_lib_ldflag(['-Wl,-Bstatic', '-Wl,-Bdynamic']);
   $config->add_static_lib('foo');
-  
+
 =head2 ld_optimize
 
   my $ld_optimize = $config->ld_optimize;
   $config->ld_optimize($ld_optimize);
 
-Gets and sets the C<ld_optimize> field.
-
-This field is the option for optimization of the linker such as C<-O3>, C<-O2>, C<-g3 -O0>.
+Gets and sets the C<ld_optimize> field, an optimization option for the linker L</"ld">.
 
 Examples:
 
   $config->ld_optimize("-O3");
 
+=head2 before_link_cbs
+
+  my $before_link_cbs = $config->before_link_cbs;
+  $config->before_link_cbs($before_link_cbs);
+
+Gets and sets the C<before_link_cbs> field, an array reference of callbacks called just before the link command L</"ld"> is executed.
+
+The 1th argument of the callback is a L<SPVM::Builder::Config> object.
+
+The 2th argument of the callback is a L<SPVM::Builder::LinkInfo> object.
+
 =head2 force
 
   my $force = $config->force;
@@ -1129,11 +1130,11 @@ Examples:
 
 Gets and sets the C<force> field.
 
-If this field is a true value, the compilation and link are forced without caching.
+If this field is a true value, the compilation and linking is forced without using the cache.
 
-If this field is a false value, they are not forced.
+If this field is a false value except for undef, the compilation and linking uses the cached if the cache exists.
 
-If this field is undef, whether they are forced or not is determined by other conditions.
+If this field is undef, whether the compilation and linking is forced is not specified.
 
 =head2 quiet
 
@@ -1142,29 +1143,25 @@ If this field is undef, whether they are forced or not is determined by other co
 
 Gets and sets the C<quiet> field.
 
-If this field is a true value, messages of the compiler and linker are output.
+If this field is a true value, compiler and linker messages are output.
 
-If this field is a false value, the messages are not output.
+If this field is a false value except for undef, compiler and linker messages are are not output.
 
-If this field is undef, whether the messages are output or not is determined by other conditions.
+If this field is undef, whether compiler and linker messages are output is not specified.
 
 =head2 class_name
 
   my $basic_type_name = $config->class_name;
   $config->class_name($basic_type_name);
 
-Gets and sets the C<class_name> field.
-
-This field is the class name of this config.
+Gets and sets the C<class_name> field, the class name configured by this config.
 
 =head2 file
 
   my $file = $config->file;
   $config->file($file);
 
-Gets and sets the C<file> field.
-
-This field is the path of the config file.
+Gets and sets the C<file> field, the file path of this config.
 
 =head2 file_optional
 
@@ -1173,16 +1170,20 @@ This field is the path of the config file.
 
 Gets and sets the C<file_optional> field.
 
-If this field is false and the file that is given by the L<file|/"file"> field is not found, an exception is thrown.
+If this field is a true value, even if the L<file|/"file"> field is not given, an exception is not thrown.
 
 =head2 output_type
 
   my $output_type = $config->output_type;
   $config->output_type($output_type);
 
-Gets and sets the C<output_type> field.
+Gets and sets the C<output_type> field, an output type of the output file generated by the linker L</"ld">.
 
-This field is the output type of the linker. C<"dynamic_lib">, C<"static_lib"> and C<"exe"> are available.
+If thie field is C<dynamic_lib>, the output file is a dynamic link library.
+
+If thie field is C<static_lib>, the output file is a static link library.
+
+If thie field is C<exe>, the output file is an executable file.
 
 =head2 disable_resource
 
@@ -1191,7 +1192,7 @@ This field is the output type of the linker. C<"dynamic_lib">, C<"static_lib"> a
 
 Gets and sets the C<disable_resource> field.
 
-If this value is true, All resources loaded by the L</"use_resource"> method is disabled.
+If this value is a true value, all resources loaded by the L</"use_resource"> method are disabled.
 
 =head1 Class Methods
 
@@ -1199,13 +1200,7 @@ If this value is true, All resources loaded by the L</"use_resource"> method is
 
   my $config = SPVM::Builder::Config->new(%fields);
 
-Create a C<SPVM::Builder::Config> object with L<fields|/"Fields">.
-
-Exceptions:
-
-If the L</"file_optional"> field is not set to a true value, the L</"file"> field must be passed. Otherwise an exception is thrown.
-
-Default Field Values:
+Creates a new C<SPVM::Builder::Config> object with L<fields|/"Fields">, and returns it.
 
 If a field is not defined, the field is set to the following default value.
 
@@ -1213,27 +1208,27 @@ If a field is not defined, the field is set to the following default value.
 
 =item * L</"class_name">
 
-  undef
+undef
 
 =item * L</"file">
 
-  undef
+undef
 
 =item * L</"file_optional">
 
-  0
+0
 
 =item * L</"ext">
 
-  undef
+undef
 
 =item * L</"quiet">
 
-  undef
+undef
 
 =item * L</"force">
 
-  undef
+undef
 
 =item * L</"cc">
 
@@ -1241,65 +1236,71 @@ The C<$Config{cc}> of the L<Config> class.
 
 =item * L</"ccflags">
 
-  []
+[]
 
 =item * L</"dynamic_lib_ccflags">
 
 Windows:
 
-  []
+[]
 
-Others:
+Other OSs:
 
-  ['-fPIC']
+["-fPIC"]
 
 =item * L</"thread_ccflags">
 
 Windows:
 
-  []
+[]
 
-Others:
+Other OSs:
 
-  ['-pthread']
+["-pthread"]
 
 =item * L</"std">
 
-  undef
+undef
 
 =item * L</"optimize">
 
-  "-O3"
+"-O3"
 
 =item * L</"include_dirs">
 
-  []
+[]
 
 =item * L</"spvm_core_include_dir">
 
-The header including directory of the SPVM core is created from the class file of the loaded L<SPVM::Builder::Config> class. 
+The SPVM core header file search directory.
 
-The value looks like C<path/SPVM/Builder/include>.
+This is generated from the path of the config file L</"file">.
+
+This is something like C</path/SPVM/Builder/include>.
 
 =item * L</"native_include_dir">
 
-If the L</"file"> field is defined, the path of the header including directory is created from the L</"file"> field.
+The header file search directory for this natvie class.
 
-The value looks like C<path/Foo.native/include>.
+This is generated from the path of the config file L</"file">.
+
+This is something like C</path/Foo.native/include>.
 
 =item * L</"native_src_dir">
 
-If the L</"file"> field is defined, the path of the source directory is created from the L</"file"> field.
+The source file search directory for this natvie class.
 
-The value looks like C<path/Foo.native/src>.
+This is generated from the path of the config file L</"file">.
+
+This is something like C</path/Foo.native/src>.
 
 =item * L</"source_files">
 
-  []
+[]
 
 =item * L</"before_compile_cbs">
 
-  []
+[]
 
 =item * L</"ld">
 
@@ -1307,113 +1308,115 @@ The C<$Config{ld}> of the L<Config> class.
 
 =item * L</"ldflags">
 
+[]
+
 =item * L</"dynamic_lib_ldflags">
 
 Windows:
 
-  ["-mdll", "-s"]
+["-mdll", "-s"]
 
 Other OSs:
 
-  ['-shared']
+["-shared"]
 
 =item * L</"thread_ldflags">
 
 Windows:
 
-  []
+[]
 
 Other OSs:
 
-  ['-pthread']
+["-pthread"]
   
 =item * L</"static_lib_ldflag">
 
-  ['-Wl,-Bstatic', '-Wl,-Bdynamic']
+["-Wl,-Bstatic", "-Wl,-Bdynamic"]
 
 =item * L</"ld_optimize">
 
-  "-O2"
+"-O2"
 
 =item * L</"lib_dirs">
 
-  []
+[]
 
 =item * L</"libs">
 
-  []
+[]
 
 =item * L</"before_link_cbs">
 
-  []
+[]
 
 =item * L</"output_type">
 
-  "dynamic_lib"
+"dynamic_lib"
 
 =back
 
-Examples:
+Exceptions:
 
-  my $config = SPVM::Builder::Config->new(file => __FILE__);
+The \"file" field must be defined. Otherwise an exception is thrown.
 
 =head2 new_c
   
   my $config = SPVM::Builder::Config->new_c(file => __FILE__);
 
-Calls the L</"new"> method and sets th L</"ext"> field to C<c>.
+Calls the L</"new"> method and sets the L</"ext"> field to C<c>, and returns the return value of the L</"new_c"> method.
 
 =head2 new_c99
   
   my $config = SPVM::Builder::Config->new_c99(file => __FILE__);
 
-Calls the L</"new_c"> method and sets the L</"std"> field to C<c99>.
+Calls the L</"new_c"> method and sets the L</"std"> field to C<c99>, and returns the return value of the L</"new_c"> method.
 
 =head2 new_c11
   
   my $config = SPVM::Builder::Config->new_c11(file => __FILE__);
 
-Calls the L</"new_c"> method and sets the L</"std"> field to C<c11>.
+Calls the L</"new_c"> method and sets the L</"std"> field to C<c11>, and returns the return value of the L</"new_c"> method.
 
 =head2 new_gnu99
   
   my $config = SPVM::Builder::Config->new_gnu99(file => __FILE__);
 
-Calls the L</"new_c"> method and sets the L</"std"> field to C<gnu99>.
+Calls the L</"new_c"> method and sets the L</"std"> field to C<gnu99>, and returns the return value of the L</"new_c"> method.
 
 =head2 new_gnu11
   
   my $config = SPVM::Builder::Config->new_gnu11(file => __FILE__);
 
-Calls the L</"new_c"> method and sets the L</"std"> field to C<gnu11>.
+Calls the L</"new_c"> method and sets the L</"std"> field to C<gnu11>, and returns the return value of the L</"new_c"> method.
 
 =head2 new_cpp
   
   my $config = SPVM::Builder::Config->new_cpp(file => __FILE__);
 
-Calls the L</"new"> method and sets the L</"ext"> field to C<cpp> and sets the L</"cc"> field to a C<C++> compiler and sets the L</"ld"> field to a C<C++> linker.
+Calls the L</"new"> method and sets the L</"ext"> field to C<cpp> and sets the L</"cc"> field to a C<C++> compiler and sets the L</"ld"> field to a C<C++> linker, and returns the return value of the L</"new"> method.
 
-If C<$Config{gccversion}> of the L<Config> class matches the regex C</\bclang\b/i>, the L</"cc"> field and the L</"ld"> field are set to C<clang++>.
+If the compiler included in C<$Config{gccversion}> is C<clang>, the L</"cc"> field and the L</"ld"> field are set to C<clang++>.
 
-Otherwise the L</"cc"> field and the L</"ld"> field are set to set to C<g++>.
+Otherwise the L</"cc"> field and the L</"ld"> field are set to C<g++>.
 
 =head2 new_cpp11
   
   my $config = SPVM::Builder::Config->new_cpp11(file => __FILE__);
 
-Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++11>.
+Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++11>, and returns the return value of the L</"new_cpp"> method.
 
 =head2 new_cpp14
   
   my $config = SPVM::Builder::Config->new_cpp14(file => __FILE__);
 
-Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++14>.
+Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++14>, and returns the return value of the L</"new_cpp"> method.
 
 =head2 new_cpp17
   
   my $config = SPVM::Builder::Config->new_cpp17(file => __FILE__);
 
-Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++17>.
+Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++17>, and returns the return value of the L</"new_cpp"> method.
 
 =head1 Instance Methods
 
@@ -1421,31 +1424,25 @@ Calls the L</"new_cpp"> method and sets the L</"std"> field to C<c++17>.
 
   $config->add_ccflag(@ccflags);
 
-Adds values at the end of the L</"ccflags"> field.
+Adds compiler options at the end of the L</"ccflags"> field.
 
 =head2 add_ldflag
 
   $config->add_ldflag(@ldflags);
 
-Adds values at the end of the L</"ldflags"> field.
+Adds linker options at the end of the L</"ldflags"> field.
 
 =head2 add_include_dir
 
   $config->add_include_dir(@include_dirs);
 
-Adds values at the end of the L</"include_dirs"> field.
-
-=head2 add_lib_dir
-
-  $config->add_lib_dir(@lib_dirs);
-
-Adds values after the last element of  C<lib_dirs> field.
+Adds header file search directories at the end of the L</"include_dirs"> field.
 
 =head2 add_source_file
 
   $config->add_source_file(@source_files);
 
-Adds a native source file at the end of the L</"source_files"> field.
+Adds source files used by this native class at the end of the L</"source_files"> field.
 
 Examples:
 
@@ -1467,22 +1464,11 @@ Examples:
     # Do something
   });
 
-=head2 add_before_link_cb
+=head2 add_lib_dir
 
-  $config->add_before_link_cb(@before_link_cbs);
+  $config->add_lib_dir(@lib_dirs);
 
-Adds callbacks called just before the link command L</"ld"> is executed at the end of the L</"before_link_cbs"> field.
-
-Examples:
-
-  $config->add_before_link_cb(sub {
-    my ($config, $link_info) = @_;
-    
-    my $object_files = $link_info->object_files;
-    
-    # Do something
-    
-  });
+Adds library search directories at the end of the L</"lib_dirs"> field.
 
 =head2 add_lib
 
@@ -1503,76 +1489,113 @@ Examples:
 
   $config->add_static_lib(@libs);
 
-Adds library names or L<SPVM::Builder::LibInfo> objects at the end of the L</"libs"> field.
-
-C<static> field is set to a true value.
+Adds library names or L<SPVM::Builder::LibInfo> objects at the end of the L</"libs"> field with the C<static> field set to a true value.
 
 Examples:
 
   $config->add_static_lib('gsl');
   $config->add_static_lib('gsl', 'z');
-  $config->add_static_lib(
-    SPVM::Builder::LibInfo->new(config => $config, name => 'gsl'),
-    SPVM::Builder::LibInfo->new(config => $config, name => 'z', abs => 1),
-  );
+
+=head2 add_before_link_cb
+
+  $config->add_before_link_cb(@before_link_cbs);
+
+Adds callbacks called just before the link command L</"ld"> is executed at the end of the L</"before_link_cbs"> field.
+
+Examples:
+
+  $config->add_before_link_cb(sub {
+    my ($config, $link_info) = @_;
+    
+    my $object_files = $link_info->object_files;
+    
+    # Do something
+    
+  });
 
 =head2 use_resource
 
   my $resource = $config->use_resource($resource_name);
   my $resource = $config->use_resource($resource_name, %options);
 
-Loads a resource by the resource name $resource_name using the L<SPVM::Builder::Resource|/"new"> method in the L<SPVM::Builder::Resource> class, and returns a L<SPVM::Builder::Resource> object.
-  my $resource = SPVM::Builder::Resource->new(class_name => $resource_name);
-  $config->use_resource($resource);
+Loads a resource(a L<SPVM::Builder::Resource> object) given a resource name and options, and returns it.
 
-If the options %options are given, they are used as the options of the L<SPVM::Builder::Resource|/"new"> method in the L<SPVM::Builder::Resource> class.
+See L<SPVM::Document::Resource> about creating and using resources.
 
-  my $resource = SPVM::Builder::Resource->new(
-    class_name => 'Resource::Zlib',
-    mode => 'production',
-    argv => ['foo', 'bar'],
-  );
-  $config->use_resource($resource);
+Options:
+
+=over 2
+
+=item * mode
+
+The same as the L<mode|SPVM::Builder::Resource/"mode"> option in the new method in the SPVM::Builder::Resource class.
+
+=item * argv
+
+The same as the L<argv|SPVM::Builder::Resource/"argv"> option in the new method in the SPVM::Builder::Resource class.
+
+=back
 
 Examples:
 
   $config->use_resource('Resource::Zlib');
+  $config->use_resource('Resource::Foo', mode => 'mode1', argv => ['args1', 'args2']);
+
+=head2 get_resource
+
+  my $resource = $config->get_resource($resource_name);
+
+Gets a resource(a L<SPVM::Builder::Resource> object) loaded by the L</"use_resource"> method given a resource name, and returns it.
 
 =head2 get_resource_names
 
   my $resource_names = $config->get_resource_names;
 
-Gets resource names loaded by the L/"use_resource/"> method.
+Returns resource names loaded by the L</"use_resource"> method.
 
 =head2 load_config
 
   my $config = $config->load_config($config_file, @argv);
 
-Loads a config file, and returns a L<SPVM::Builder::Config> object. The argument @argv is set to the @ARGV of the config file.
+Loads a config file, and returns a L<SPVM::Builder::Config> object.
+
+The argument @argv is set to the @ARGV of the config file.
 
 =head2 load_base_config
 
   my $config = $config->load_base_config($config_file, @argv);
 
-Loads a base config file like C<Foo.config>. This method is the alias for the following method call using L</"load_mode_config">.
+Loads the base config file of the config file given as the argument, and returns a L<SPVM::Builder::Config> object.
 
-  my $config = $config->load_mode_config($config_file, undef, @argv);
+The base config file is the config file that removes its mode from the config file given as the argument.
+
+The argument @argv is set to the @ARGV of the base config file.
+
+If the config file given as the argument is C</path/Foo.devel.config>, the base config file is C</path/Foo.config>.
+
+Examples:
+
+  my $config = SPVM::Builder::Config::Exe->load_base_config(__FILE__);
 
 =head2 load_mode_config
 
   my $config = $config->load_mode_config($config_file, $mode, @argv);
 
-Loads a mode config file like C<Foo.mode.config>.
+Loads the mode config file of the config file given as the argument, and returns a L<SPVM::Builder::Config> object.
 
-At first, removes the string matching the regex C<(\.[^\.]+)?\.config$> from the base name of the config file $config_file.
+The mode config file is the config file that removes its mode(if the mode exists) from the config file given as the argument and added the mode given as the argument.
 
-Next, if the mode $mode is defined, C<.$mode.config> is added to $config_file. Otherwise C<.config> is added.
+The argument @argv is set to the @ARGV of the mode config file.
 
-Last, L</"load_config"> is called with the modified name of the config file.
+If the config file given as the argument is C</path/Foo.config> and the mode given as the argument is C<production>, the mode config file is C</path/Foo.production.config>.
+
+If the config file given as the argument is C</path/Foo.devel.config> and the mode given as the argument is C<production>, the mode config file is C</path/Foo.production.config>.
+
+  my $config = SPVM::Builder::Config::Exe->load_mode_config(__FILE__, "production");
 
 =head2 get_loaded_config_files
 
-Gets the config files loaded by the L</"load_config"> method.
+Returns the config files loaded by the L</"load_config"> method.
 
 =head2 clone
 
