@@ -1004,9 +1004,9 @@ sub compile_module_precompile_source_file {
     mkpath $build_src_dir;
     
     my $class_file = $basic_type->_get_class_file;
-    my $precompile_source = $self->runtime->build_precompile_module_source($basic_type);
+    my $precompile_source = $self->runtime->build_precompile_class_source($basic_type);
     
-    $builder_cc->build_precompile_module_source_file(
+    $builder_cc->build_precompile_class_source_file(
       $basic_type_name,
       {
         output_dir => $build_src_dir,
